log using inlf_8901.log, replace
/************************************************/
/* LFP Regressions with March CPS (1989-2001)   */
/* Coile, Duggan, Guo 							*/
/* January 10, 2015 							*/
/************************************************/
clear all
set more off
set matsize 5000

use cpsmaster.dta, clear

/* For all regressions, we weight by a_fnlwgt, the Basic(Final) Person Weight. 
It is equal to zero for populations not sampled in the other monthly surveys 
(Armed forces, Hispanic oversample) */

/*Since county data is only availably for 1996 and later, we don't do a county-level analysis for 1989-2001*/

// Base
local reg8901 vet black other hispanic yearDV10-yearDV21

foreach x of varlist inlf {
local outreg reg_`x'_8901.xls
areg `x' `reg8901' if a_age>=25 & a_age<=34 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', replace keep (vet black other hispanic) ctitle (m1,base)
areg `x' `reg8901' if a_age>=35 & a_age<=54 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m2,base)
areg `x' `reg8901' if a_age>=55 & a_age<=64 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m3,base)
areg `x' `reg8901' if a_age>=65 & a_age<=74 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m4,base)
areg `x' `reg8901' if a_age<=64 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m5,base)
}

// State x Year FEs 
local reg8901 vet black other hispanic yearDV10-yearDV21 year10state* year11state* year12state* year13state* year14state* year15state* year16state* year17state* year18state* year19state* year20state* year21state* year22state*

foreach x of varlist inlf {
local outreg reg_`x'_8901.xls
areg `x' `reg8901' if a_age>=25 & a_age<=34 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m1,stateFE)
areg `x' `reg8901' if a_age>=35 & a_age<=54 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m2,stateFE)
areg `x' `reg8901' if a_age>=55 & a_age<=64 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m3,stateFE)
areg `x' `reg8901' if a_age>=65 & a_age<=74 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m4,stateFE)
areg `x' `reg8901' if a_age<=64 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet black other hispanic) ctitle (m5,stateFE)
}

// State UR
gen vet_stateur = vet*demeanedstur

local reg8901 vet black other hispanic vet_stateur yearDV10-yearDV21 year10state* year11state* year12state* year13state* year14state* year15state* year16state* year17state* year18state* year19state* year20state* year21state* year22state*

foreach x of varlist inlf {
local outreg reg_`x'_8901.xls
areg `x' `reg8901' if a_age>=25 & a_age<=34 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m1,stateUR)
areg `x' `reg8901' if a_age>=35 & a_age<=54 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m2,stateUR)
areg `x' `reg8901' if a_age>=55 & a_age<=64 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m3,stateUR)
areg `x' `reg8901' if a_age>=65 & a_age<=74 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m4,stateUR)
areg `x' `reg8901' if a_age<=64 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m5,stateUR)
}

// Add State x Vet FEs

local reg8901 vet black other hispanic vet_stateur statevet* statenovet* yearDV10-yearDV21 year10state* year11state* year12state* year13state* year14state* year15state* year16state* year17state* year18state* year19state* year20state* year21state* year22state*

foreach x of varlist inlf {
local outreg reg_`x'_8901.xls
areg `x' `reg8901' if a_age>=25 & a_age<=34 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m1,statevet)
areg `x' `reg8901' if a_age>=35 & a_age<=54 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m2,statevet)
areg `x' `reg8901' if a_age>=55 & a_age<=64 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m3,statevet)
areg `x' `reg8901' if a_age>=65 & a_age<=74 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m4,statevet)
areg `x' `reg8901' if a_age<=64 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur black other hispanic) ctitle (m5,statevet)
}

// Lagged State UR
gen vet_stateur_1 = vet*demeanedstur_1

local reg8901 vet black other hispanic vet_stateur_1 yearDV10-yearDV21 year10state* year11state* year12state* year13state* year14state* year15state* year16state* year17state* year18state* year19state* year20state* year21state* year22state*

foreach x of varlist inlf {
local outreg reg_`x'_8901.xls
areg `x' `reg8901' if a_age>=25 & a_age<=34 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m1,lagstUR)
areg `x' `reg8901' if a_age>=35 & a_age<=54 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m2,lagstUR)
areg `x' `reg8901' if a_age>=55 & a_age<=64 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m3,lagstUR)
areg `x' `reg8901' if a_age>=65 & a_age<=74 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m4,lagstUR)
areg `x' `reg8901' if a_age<=64 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m5,lagstUR)
}

// Lagged State x Vet FEs

local reg8901 vet black other hispanic vet_stateur_1 statevet* statenovet* yearDV10-yearDV21 year10state* year11state* year12state* year13state* year14state* year15state* year16state* year17state* year18state* year19state* year20state* year21state* year22state*

foreach x of varlist inlf {
local outreg reg_`x'_8901.xls
areg `x' `reg8901' if a_age>=25 & a_age<=34 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m1,lagstvet)
areg `x' `reg8901' if a_age>=35 & a_age<=54 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m2,lagstvet)
areg `x' `reg8901' if a_age>=55 & a_age<=64 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m3,lagstvet)
areg `x' `reg8901' if a_age>=65 & a_age<=74 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m4,lagstvet)
areg `x' `reg8901' if a_age<=64 & year>=1989 & year<=2001 [aw=a_fnlwgt], a(a_age) cluster(state)
outreg2 using `outreg', keep (vet vet_stateur_1 black other hispanic) ctitle (m5,lagstvet)
}

log close
